SetAddElementsRequest

Struct SetAddElementsRequest 

pub struct SetAddElementsRequest<S: IntoBytes, E: IntoBytesIterable> { /* private fields */ }
Request to add elements to the given set. Creates the set if it does not exist.

Arguments

  • cache_name - The name of the cache containing the set.
  • set_name - The name of the set to add an element to.
  • elements - The elements to add. Must be able to be converted to a Vec<u8>.

Optional Arguments

  • collection_ttl - The time-to-live for the collection. If not provided, the client’s default time-to-live is used.

Examples

Assumes that a CacheClient named cache_client has been created and is available.

use momento::cache::{CollectionTtl, SetAddElementsResponse, SetAddElementsRequest};
let set_name = "set";

let add_elements_request = SetAddElementsRequest::new(
    cache_name,
    set_name,
    vec!["value1", "value2"]
).ttl(CollectionTtl::default());

match cache_client.send_request(add_elements_request).await {
    Ok(_) => println!("Elements added to set"),
    Err(e) => eprintln!("Error adding elements to set: {}", e),
}

Implementations

Source

impl<S: IntoBytes, E: IntoBytesIterable> SetAddElementsRequest<S, E>

pub fn new(cache_name: impl Into<String>, set_name: S, elements: E) -> Self

Constructs a new SetAddElementsRequest.

pub fn ttl(self, collection_ttl: impl Into<Option<CollectionTtl>>) -> Self

Set the time-to-live for the collection.