Function

Struct Function 

pub struct Function { /* private fields */ }
Description of a Function in Momento.

Implementations

Source

impl Function

pub fn name(&self) -> &str

Name of the function.

pub fn description(&self) -> &str

Description of the function.

pub fn function_id(&self) -> &str

Unique identifier for the function.

pub fn version(&self) -> u32

Currently active version of the function.

pub fn latest_version(&self) -> u32

Latest available version of the function.

pub fn concurrency_limit(&self) -> u32

The allowed amount of concurrent invocations for this function

pub fn last_updated_at(&self) -> &str

Human-readable timestamp for when the function was last modified. Will return as a UTC timestamp in ISO 8601 format.