pub struct FunctionVersion {
pub environment: HashMap<String, EnvironmentValue>,
/* private fields */
}Expand description
A configuration set representing a specific version of a Function in Momento.
Fields
environment: HashMap<String, EnvironmentValue>The environment variables available to this function via the WASI environment interface.
Implementations
Sourceimpl FunctionVersion
impl FunctionVersion
Sourcepub fn version_id(&self) -> &FunctionVersionId
pub fn version_id(&self) -> &FunctionVersionId
The unique identifier for this function version.
Sourcepub fn wasm_version_id(&self) -> &WasmVersionId
pub fn wasm_version_id(&self) -> &WasmVersionId
The wasm ID this function uses.
Sourcepub fn environment(&self) -> &HashMap<String, EnvironmentValue>
pub fn environment(&self) -> &HashMap<String, EnvironmentValue>
The environment variables available to this function via the WASI environment interface.