pub struct Function { /* private fields */ }Expand description
Description of a Function in Momento.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Description of the function.
Sourcepub fn function_id(&self) -> &str
pub fn function_id(&self) -> &str
Unique identifier for the function.
Sourcepub fn latest_version(&self) -> u32
pub fn latest_version(&self) -> u32
Latest available version of the function.
Sourcepub fn concurrency_limit(&self) -> u32
pub fn concurrency_limit(&self) -> u32
The allowed amount of concurrent invocations for this function
Sourcepub fn last_updated_at(&self) -> &str
pub fn last_updated_at(&self) -> &str
Human-readable timestamp for when the function was last modified. Will return as a UTC timestamp in ISO 8601 format.